@@ -1,8 +1,8 @@
 
-from django.template import Library, Node
-from django.template.base import TemplateSyntaxError
+from django.template import Library, Node, Variable
+from django.template.base import TemplateSyntaxError, VariableDoesNotExist
 
-from dynamic_validation.models import Violation
+from dynamic_validation import models
 register = Library()
 
 __all__ = ('violations_for', )
@@ -20,10 +20,13 @@ def violations_for(parser, token):
 
 class ViolationsForNode(Node):
     def __init__(self, obj, var_name):
-        self.obj = obj
+        self.obj = Variable(obj)
         self.var_name = var_name
 
     def render(self, context):
-        violations = Violation.objects.get_by_validation_object(context[self.obj])
-        context[self.var_name] = violations
+        try:
+            obj = self.obj.resolve(context)
+            violations = models.Violation.objects.get_by_validation_object(obj)
+            context[self.var_name] = models.ViolationsWrapper(violations)
+        except VariableDoesNotExist: pass
         return ''
\ No newline at end of file
