@@ -1,6 +1,7 @@
 
 from django.contrib.contenttypes.models import ContentType
 
+from dynamic_rules import models as rule_models
 from dynamic_validation import models
 
 __all__ = ('get_violation', )
@@ -9,9 +10,10 @@ def get_violation(**kwargs):
     return models.Violation(
         pk=kwargs.get('pk'),
         key=kwargs.get('key', "abc"),
-        rule=kwargs.get("rule", models.Rule(pk=100)),
+        rule=kwargs.get("rule", rule_models.Rule(pk=100)),
         violated_fields=kwargs.get("violated_fields", {'field': 'one'}),
         content_type=kwargs.get("content_type", ContentType(pk=10)),
         validation_object_id=kwargs.get("validation_object_id", 1),
         message=kwargs.get('message'),
+        acceptable=kwargs.get('acceptable'),
     )
\ No newline at end of file
